PERRIS: Woman ordered hit on father of her child, police say - Press Enterprise
Description: PERRIS: Woman ordered hit on father of her child, police say | perris, police, exchange, thought, gunfire, father, times, hit, first, turned
Keywords: perris, police, exchange, thought, gunfire, father, times, hit, first, turned

Log in Subscribe Today Customer Service P-Edition Advertise Top Workplaces UnidosSC.com

- Home
- News
- Sports
- Entertainment
- Business
- Life
- Opinion
- Blogs
- Photos
- Obits

Register Connect

- CARS
- JOBS
- HOMES
- Shop
- Classifieds

- News

  ### TEMECULA: Land for water park could fetch $2.85 million

- News

  ### MURRIETA: City bids farewell to outgoing fire chief

- News

  ### STATE SENATE: Jeff Stone raises prospect of loan to help 4 Inland cities

- News

  ### CORONA: Candlelight vigil set for 18-year-old killed in crash

### News

# PERRIS: Woman ordered hit on father of her child, police say

Tweet

- ### Trending

- Riverside Yellow Pages

- ### THINGS TO DO

BY SARAH BURGE / STAFF WRITER

Published: Jan. 14, 2015 Updated: 4:49 p.m.

### PERRIS: Woman ordered hit on father of her child, police say

Print Photo
Share
Pin It
More Galleries
ADVERTISEMENT
Judy Avalos, 20, was charged with conspiracy to commit murder after a shooting near Perris that injured her boyfriend.
RIVERSIDE COUNTY SHERIFF'S DEPT./CONTRIBUTED IMAGE
Related article »

After a man was shot four times in an exchange of gunfire near Perris, police at first thought it might have been a drug deal gone wrong.

But their focus quickly turned to the 20-year-old mother of the man’s child. She is now accused of orchestrating an attempt to kill him. The man survived his injuries.

Judy Avalos, of Perris, was arrested at the hospital where she was visiting her injured boyfriend the day after the Dec. 30 shooting. She has pleaded not guilty to conspiracy to commit murder and is being held in lieu of $1 million bail.

Neither the gunman, nor a man believed to have accompanied him, have been identified, Lt. David Lelevier said. The gunman’s compensation for the shooting appears to have been not a cash payment but a romantic relationship with Avalos, he said.

Defense attorney Nic Cocis said Avalos did not seek to have her boyfriend killed. Avalos believed he was going to be beaten up, not shot, Cocis said.

The shooting was reported to the Riverside County Sheriff’s Department about 9:30 p.m. in the 23300 block of Edmond Street in the unincorporated area known as Good Hope.

Avalos told investigators that she and her 24-year-old boyfriend had gone to Bakersfield together to retrieve a Jeep and she followed him back to Riverside County in her pickup, search warrant documents say. The boyfriend waited outside in the Jeep while Avalos went into her mother’s house to pick up their 4-year-old daughter. Avalos said she had been inside about 10 minutes when she heard a hail of gunfire and dropped to the floor.

After the gunfire stopped, Avalos said she went outside to find her boyfriend, with four gunshot wounds, walking up the driveway and holding a gun, Investigator Robert Cornett wrote in search warrant documents.

Deputies later discovered a car, which had been reported stolen, abandoned a few blocks away. It was riddled with bullet holes.

The boyfriend told investigators that the shooter and another man were in a white car that pulled up next to him while he was parked on Edmond Street, search warrant documents say. He said the car had driven past him, stopped for a few minutes at the dead end of the street, then pulled up next to him with a window down.

The men in the car told him they were lost and asked for directions to Highway 74. A minute or two later, he said, one of the men pulled a gun and started shooting at him. He said he grabbed the gun under his seat and fired back at them as the car drove off, search warrant documents say.

“(He) went on to say that Avalos had a strange conversation with him a few days prior,” Cornett wrote. “He said she called him up and asked him if he had been shot at.”

When investigators questioned Avalos about the conversation, she said she had had a dream about it, adding that “when she has a dream about things, they come true,” Cornett wrote.

She denied having anything to do with the shooting and let deputies download data from her cell phone.

Investigators said they found several suspicious texts, written in Spanish, that had been deleted from the phone. Avalos wrote to someone saying she wanted them to take out only her boyfriend and that it had to be tonight – Dec. 30, search warrant papers say.

She wrote that he would be in a Jeep parked in front of her mother’s house and the person replied that he was set with two people for tonight. At 9:24 p.m., Avalos texted to say they were there. The other person replied, telling Avalos to delete the text messages before “they do their job,” Cornett wrote.

After she was arrested, Avalos told investigators her boyfriend had been mistreating her and not letting her leave the house to go out with her friends, Cornett wrote. Avalos said he would point a gun at her and tell her he was going to kill her, but that she had never reported it to police, search warrant papers say.

“She said they had been arguing all week and she was just ‘mad’ at him,” Cornett wrote. “She said she was wrong for what she did but did not know any other way to get out of the relationship.”

### More from Breaking News

- #### FONTANA: Fontana High search fails to find explosives (UPDATE 2)

- #### MURRIETA: Taco Bell robbed at gunpoint

- #### HWY. 330: Tenant dispute prompts mountain highway chase, arrest

COMMENTS | PRINT | EMAIL |

### Join the conversation

Comments are encouraged, but you must follow our User Agreement

Keep it civil and stay on topic. No profanity, vulgarity, racial slurs or personal attacks. People who harass others or joke about tragedies will be blocked. By posting your comment, you agree to allow Freedom Communications, Inc. the right to republish your name and comment in additional Freedom publications without any notification or payment.

Return to Top

- Home
- News
- Cities
- Sports
- Entertainment
- Business
- Life
- Opinion
- Blogs
- Photos
- Obituaries
- Weather
- Real Estate
- Jobs
- Cars
- Classifieds

Copyright ©
The Press-Enterprise. All Rights Reserved.
About Us | Privacy Policy | User Agreement | Site Map
Powered by the Parse.ly Publisher Platform (P3).